@@ -4,7 +4,6 @@ import boto3
 from botocore.exceptions import ClientError
 from django.conf import settings
 from django.core.mail import EmailMessage
-# from openlxp_notifications.media import HTML_files
 logger = logging.getLogger('dict_config_logger')
 
 
@@ -65,7 +64,7 @@ def send_notifications(email, sender, email_configuration):
 
     # The HTML body of the email.
     file_name = 'Email_Template.html'
-    BODY_HTML = open(file_name).read().format(
+    BODY_HTML = open('media/' + file_name).read().format(
         paragraph=email_configuration.get('Email_Content'),
         signature=email_configuration.get('Signature'),
         email_us=email_configuration.get('Email_Us'),
